<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>KWin::MultitaskViewEffect</name>
    <message>
        <source>Drag upwards to remove</source>
        <translation>向上拖拽删除</translation>
    </message>
    <message>
        <source>No windows</source>
        <translation>无打开的窗口</translation>
    </message>
</context>
</TS>